# SPDX-License-Identifier: CECILL-C

module SpeechDatasets

using JSON
import AudioSources
using SpeechFeatures
import MLUtils

export
    # ManifestItem
    Recording,
    Annotation,
    load,

    # Manifest interface
    writemanifest,
    readmanifest,

    # Builder interface
    DatasetBuilder,
    download,
    prepare,

    # Corpora
    MLLIBRISPEECH,
    MINILIBRISPEECH,
    TIMIT,
    INADIACHRONY,
    AVID,
    SPEECH2TEX,

    # Lexicon
    CMUDICT,
    TIMITDICT,
    MFAFRDICT,

    # Dataset
    SpeechDatasetInfos,
    SpeechDataset,
    dataset

include("speechcorpus.jl")
include("manifest_item.jl")
include("manifest_io.jl")
include("dataset.jl")

# Supported corpora
include.("corpora/".*filter(contains(r"\.jl$"), readdir(joinpath(@__DIR__, "corpora"))))

include("lexicons.jl")

end
